@@ -13,8 +13,8 @@ irm_cr<-function(relyrs=NULL,recapyrs=NULL,N=NULL,recapharv=NULL,recaprel=NULL,h
     if(is.null(recaprel)) stop("Missing recovery matrix for fish released with tag removed.")
     if(is.null(hlambda)) stop("hlambdas (reporting rates) for harvested fish) are missing.")
     if(is.null(rlambda)) stop("hlambdas (reporting rates) for fish released with tag removedare missing.")
-    if(is.null(hphi)) stop("hphi (initial tag loss rates) for harvested fish) are missing.")
-    if(is.null(rphi)) stop("rphi (initial tag loss rates) for fish released with tag removed are missing.")
+    if(is.null(hphi)) stop("hphi (initial tag survival rates) for harvested fish) are missing.")
+    if(is.null(rphi)) stop("rphi (initial tag survival rates) for fish released with tag removed are missing.")
     if(is.null(hmrate)) stop("hmrate (hooking mortality rates) for fish are missing.")
     if(is.null(Fyr)) stop("Year designations for fishing mortality estimates (Fyr) are missing.")
     if(is.null(FAyr)) stop("Year designations for tag mortality estimates (FAyr) are missing.")
